/*
 * stdint.h
 */


#ifndef stdint_h
#define stdint_h


#include<sys/stdint.h>


#endif
